This dataset contains data gathered in a survey of Internet usage in Serbian population in the period from April to May 2008. During 90-day period, there were gathered 709 valid responses via on-line distributed questionnaire.
Aleksandar Blagotic [email protected]
Dusan Vuckovic [email protected]
However, this dataset does not contain the original data, as some random noise is added afterwards, in order to demonstrate functionality of rapport helpers.
Dataset variables can be divided into 3 sets: demographic data, Internet usage aspects and application usage/content preference.
Demographic variables
gender - respondent's gender (factor with 2 levels: "male" and "female")
age - respondent's age
dwell - dwelling (factor with 3 levels: "village", "small town" and "city")
student - is respondent a student? (factor with 2 levels: "no" and "yes")
partner - partnership status (factor with 3 levels: "single", "in a relationship" and "married")
Internet usage aspects
Following variables depict various aspects of Internet usage:
edu - time spent on-line in educational purposes (expressed in hours)
leisure - time spent on-line in leisure time (expressed in hours)
net.required - is Internet access required for your profession? (factor with 5 levels: "never", "rarely", "sometimes", "often" and "always")
net.pay - who pays for Internet access? (factor with 5 levels: "parents", "school/faculty", "employer", "self-funded" and "other")
net.use - how long is respondent using Internet? (ordered factor with 7 levels, ranging from "less than 6 months" to "more than 5 years")
Application usage and on-line content preference
These variables include data on the use of Internet applications and content available on the Internet. Practically, they contain responses from a set of 8 questions on a five-point Likert scale.
chatim - usage of chat and/or instant messaging applications
game - usage of on-line games
surf - frequency of web-surfing
email - usage of e-mail applications
download - frequency of file downloading
forum - attendance at web-forums
socnet - usage of social networking services
xxx - traffic to pornographic websites
if (FALSE) {
rapport("example", ius2008, var = "it.leisure")
}
Run the code above in your browser using DataLab